PALM-meteo: palmmeteo_stdplugins.setup_staticdriver.StaticDriverPlugin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo_stdplugins.setup_staticdriver.StaticDriverPlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.setup_staticdriver.StaticDriverPlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.setup_staticdriver.StaticDriverPlugin:
[legend]

## Public Member Functions
def | setup_model (self, *args, **kwargs)
def | setup_model (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Detailed Description

    Default setup plugin for loading domain info from static driver file.

## Member Function Documentation

## ◆ setup_model()

def palmmeteo_stdplugins.setup_staticdriver.StaticDriverPlugin.setup_model | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.SetupPluginMixin.

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/setup_staticdriver.py